SWDEV-388833 - [catch2][dtest] Sync tests migrated from dtests to catch2

Change-Id: I73664579ab9475e51db436b57ca6538aa7a8d5d7


[ROCm/hip-tests commit: 902c993615]
This commit is contained in:
SrinivasaRao
2023-11-15 14:55:06 +05:30
committed by Srinivasarao Gollamandala
parent 3e5aa93c49
commit d7fec53720
6 changed files with 952 additions and 0 deletions
@@ -0,0 +1,10 @@
#include <hip/hip_runtime.h>
extern "C" __global__ void memcpyIntKernel(int* dst, const int* src,
size_t numElements) {
int gid = (blockIdx.x * blockDim.x + threadIdx.x);
int stride = blockDim.x * gridDim.x;
for (size_t i = gid; i < numElements; i += stride) {
dst[i] = src[i];
}
};